
# Type: iri type


An IRI

URI: [:IriType](https://example.com/test62/IriType)

|  |  |  |
| --- | --- | --- |
| Parent type | | [Uriorcurie](types/Uriorcurie.md) |
| Root (builtin) type | | **URIorCURIE** |
| Representation | | str |
